searchData={"content_type":"text/markdown","items":[{"doc":"Simple, robust temporary file support for Elixir.","ref":"Briefly.html","title":"Briefly","type":"module"},{"doc":"* Create temporary files with prefix and extname options.\n* Files are removed after the requesting process exits.\n* File creation is based on [Plug.Upload](http://hexdocs.pm/plug/Plug.Upload.html)'s robust retry logic.\n* Configurable; built-in support for system environment variables and fallbacks.","ref":"Briefly.html#module-highlighted-features","title":"Highlighted Features - Briefly","type":"module"},{"doc":"The fastest way to use Briefly is with [`Mix.install/2`](https://hexdocs.pm/mix/Mix.html#install/2) (requires Elixir v1.12+):\n\n```elixir\nMix.install([\n  {:briefly, \"~> 0.5.0\"}\n])\n\n{:ok, path} = Briefly.create()\nFile.write!(path, \"My temp file contents\")\nFile.read!(path)\n# => \"My temp file contents\"\n\n# When this process exits, the file at `path` is removed\n```\n\nIf you want to use Briefly in a Mix project, you can add the above dependency to your list of dependencies in `mix.exs`.\n\nTo use Briefly outside of the context of an application's dependency tree (e.g. in an .exs file), first run `Briefly.start`.\n\nBriefly can also create a temporary directory:\n\n\n```elixir\n{:ok, dir} = Briefly.create(type: :directory)\nFile.write!(Path.join(dir, \"test.txt\"), \"Some Text\")\n# When this process exits, the directory and file are removed\n```\n\nRefer to [the documentation](http://hexdocs.pm/briefly/Briefly.html#create/1) for a list of options that are available to `Briefly.create/1` and `Briefly.create!/1`.","ref":"Briefly.html#module-usage","title":"Usage - Briefly","type":"module"},{"doc":"The default, out-of-the-box settings for Briefly are equivalent to the\nfollowing Mix config:\n\n```elixir\n# config/config.exs\nconfig :briefly,\n  directory: [{:system, \"TMPDIR\"}, {:system, \"TMP\"}, {:system, \"TEMP\"}, \"/tmp\"],\n  directory_mode: 0o755,\n  default_prefix: \"briefly\",\n  default_extname: \"\"\n```\n\n`directory` here declares an ordered list of possible directory definitions that Briefly will check in order.\n\nThe `{:system, env_var}` tuples point to system environment variables to be checked. If none of these are defined, Briefly will use the final entry: `/tmp`.\n\nYou can override the settings with your own candidates in your application Mix\nconfig (and pass `prefix` and `extname` to `Briefly.create` to override\n`default_prefix` and `default_extname` on a case-by-case basis).","ref":"Briefly.html#module-configuration","title":"Configuration - Briefly","type":"module"},{"doc":"Removes the temporary files and directories created by the process and returns their paths.","ref":"Briefly.html#cleanup/1","title":"Briefly.cleanup/1","type":"function"},{"doc":"Requests a temporary file to be created with the given options.","ref":"Briefly.html#create/1","title":"Briefly.create/1","type":"function"},{"doc":"Requests a temporary file to be created with the given options\nand raises on failure.","ref":"Briefly.html#create!/1","title":"Briefly.create!/1","type":"function"},{"doc":"Assign ownership of the given tmp file to another process.","ref":"Briefly.html#give_away/3","title":"Briefly.give_away/3","type":"function"},{"doc":"","ref":"Briefly.html#t:create_opts/0","title":"Briefly.create_opts/0","type":"type"},{"doc":"Returned when none of the root temporary directories could be accessed.","ref":"Briefly.NoRootDirectoryError.html","title":"Briefly.NoRootDirectoryError","type":"exception"},{"doc":"","ref":"Briefly.NoRootDirectoryError.html#t:t/0","title":"Briefly.NoRootDirectoryError.t/0","type":"type"},{"doc":"Returned when a temporary file cannot be written.","ref":"Briefly.WriteError.html","title":"Briefly.WriteError","type":"exception"},{"doc":"","ref":"Briefly.WriteError.html#t:t/0","title":"Briefly.WriteError.t/0","type":"type"},{"doc":"# Briefly Usage Guide\n\n```elixir\nMix.install([\n  {:briefly, \"~> 0.5.0\"}\n])\n```","ref":"usage.html","title":"Briefly Usage Guide","type":"extras"},{"doc":"Use Briefly to create a temporary file:\n\n```elixir\n{:ok, path} = Briefly.create()\n```\n\nThen you can write to the path and read the contents of the file:\n\n```elixir\nFile.write!(path, \"My temp file contents\")\nFile.read!(path)\n```\n\nWhen this process exits, the file at `path` is removed.","ref":"usage.html#temporary-files","title":"Temporary Files - Briefly Usage Guide","type":"extras"},{"doc":"Briefly can also create a temporary directory:\n\n```elixir\n{:ok, dir} = Briefly.create(type: :directory)\n```\n\nYou can use [`File.stat/1`](https://hexdocs.pm/elixir/File.html#stat/1) to check the type:\n\n```elixir\nFile.stat!(dir).type\n```\n\nWrite to a file in the directory:\n\n```elixir\ndir |> Path.join(\"test.txt\") |> File.write!(\"Some Text\")\ndir |> Path.join(\"test.txt\") |> File.read!()\n```\n\nWhen this process exits, the directory at `dir` and the files within are removed.","ref":"usage.html#temporary-directories","title":"Temporary Directories - Briefly Usage Guide","type":"extras"},{"doc":"You can always cleanup any temporary paths already created:\n\n```elixir\nBriefly.cleanup()\n```","ref":"usage.html#cleanup","title":"Cleanup - Briefly Usage Guide","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Introduces `Briefly.create(type: :device)` to return a raw IO device. https://github.com/CargoSense/briefly/pull/43. `create(directory: true)` is deprecated in favor of `create(type: :directory)`.","ref":"changelog.html#v0-5-1-2024-01-19","title":"v0.5.1 (2024-01-19) - Changelog","type":"extras"},{"doc":"This version changes the Briefly API, so read the notes below and upgrade with care.\n\n- Change the return value of `Briefly.create/1` to be either `{:ok, path}` or\n  `{:error, Exception.t()}`. The following exceptions may be returned:\n\n  - `%Briefly.NoRootDirectoryError{}` - Briefly is unable to create a root temporary\n    directory. The exception contains the temp dirs attempted.\n\n  - `%Briefly.WriteError{}` - A temporary entry cannot be created. The exception\n    contains the POSIX error code the caused the failure.\n\nFor example, if you have this:\n\n```elixir\ncase Briefly.create() do\n  {:ok, path} -> path\n  {:no_space, _} -> raise \"no space\"\n  {:too_many_attempts, _} -> raise \"too many attempts\"\n  {:no_tmp, _} -> raise \"no tmp dirs\"\nend\n```\n\n...then change it to this:\n\n```elixir\ncase Briefly.create() do\n  {:ok, path} -> path\n  {:error, %Briefly.WriteError{code: :enospc}} -> raise \"no space\"\n  {:error, %Briefly.WriteError{code: c}} when c in [:eexist, :eacces] -> raise \"too many attempts\"\n  {:error, %Briefly.NoRootDirectoryError{}} -> raise \"no tmp dirs\"\n  {:error, exception} when is_exception(exception) -> raise exception\nend\n```\n\n- Add `Briefly.give_away/3` to transfer ownership of a tmp file.\n- Deprecate the `:monitor_pid` option.\n\nIf you were previously using `:monitor_pid` like this:\n\n```elixir\n{:ok, path} = Briefly.create(monitor_pid: pid)\n```\n\n...then change it to this:\n\n```elixir\n{:ok, path} = Briefly.create()\n:ok = Briefly.give_away(path, pid)\n```","ref":"changelog.html#v0-5-0-2023-11-15","title":"v0.5.0 (2023-11-15) - Changelog","type":"extras"},{"doc":"- Fix an issue with custom tmp dirs without a trailing slash ([#24](https://github.com/CargoSense/briefly/pull/24)) @srgpqt","ref":"changelog.html#v0-4-1-2023-01-11","title":"v0.4.1 (2023-01-11) - Changelog","type":"extras"},{"doc":"**Note Briefly v0.4+ requires Elixir v1.11+.**\n\n- Add `:monitor_pid` option to `Briefly.create/1` ([#19](https://github.com/CargoSense/briefly/pull/19)) @scarfacedeb\n- Avoid folder naming conflicts with monotonic time and random padding ([#18](https://github.com/CargoSense/briefly/pull/18)) @zph\n- Add `Briefly.cleanup/0` ([#10](https://github.com/CargoSense/briefly/pull/10)) @gmalkas\n- Fix an issue where the sub directory is not created correctly ([#9](https://github.com/CargoSense/briefly/pull/9)) @Schultzer\n- Fix error reasons to conform to posix error codes ([#4](https://github.com/CargoSense/briefly/pull/4)) @ngeraedts\n- Numerous updates for CI / language changes (h/t @bryanstearns @k-cross @szajbus @devstopfix @sgerrand @mad42 @warmwaffles)","ref":"changelog.html#v0-4-0-2023-01-09","title":"v0.4.0 (2023-01-09) - Changelog","type":"extras"},{"doc":"Add support for temporary directories","ref":"changelog.html#v0-3-0-2015-09-06","title":"v0.3.0 (2015-09-06) - Changelog","type":"extras"},{"doc":"Update license","ref":"changelog.html#v0-2-1-2015-09-03","title":"v0.2.1 (2015-09-03) - Changelog","type":"extras"},{"doc":"Add create options","ref":"changelog.html#v0-2-0-2015-09-03","title":"v0.2.0 (2015-09-03) - Changelog","type":"extras"},{"doc":"Update docs","ref":"changelog.html#v0-1-1-2015-09-03","title":"v0.1.1 (2015-09-03) - Changelog","type":"extras"},{"doc":"Initial release","ref":"changelog.html#v0-1-0-2015-09-03","title":"v0.1.0 (2015-09-03) - Changelog","type":"extras"}]}